@@ -2,7 +2,7 @@ import pandas as pd
 import numpy as np
 from fuzzywuzzy import process
 
-counties=pd.read_csv('cartpy/cartpy/counties_1872_1991.csv')
+counties=pd.read_csv('../counties_1872_1991.csv')
 
 def name_to_code(name,state,year):
     df=counties[(counties['ano']==year)&(counties['estado']==state)]
